@@ -52,13 +52,19 @@ class _ForceNullParameters(object):
     # The following attribute, plus the parameters spec callback and custom
     # __setitem__ are all to handle a situation where parameters should not be
     # optional and must be Null for certain OIDs. More info at
-    # https://tools.ietf.org/html/rfc4055#page-15
+    # https://tools.ietf.org/html/rfc4055#page-15 and
+    # https://tools.ietf.org/html/rfc4055#section-2.1
     _null_algos = set([
-        '1.2.840.113549.1.1.1',  # rsassa_pkcs1v15 / rsaes_pkcs1v15 / rsa
-        '1.2.840.113549.1.1.11',  # sha256_rsa
-        '1.2.840.113549.1.1.12',  # sha384_rsa
-        '1.2.840.113549.1.1.13',  # sha512_rsa
-        '1.2.840.113549.1.1.14',  # sha224_rsa
+        '1.2.840.113549.1.1.1',    # rsassa_pkcs1v15 / rsaes_pkcs1v15 / rsa
+        '1.2.840.113549.1.1.11',   # sha256_rsa
+        '1.2.840.113549.1.1.12',   # sha384_rsa
+        '1.2.840.113549.1.1.13',   # sha512_rsa
+        '1.2.840.113549.1.1.14',   # sha224_rsa
+        '1.3.14.3.2.26',           # sha1
+        '2.16.840.1.101.3.4.2.4',  # sha224
+        '2.16.840.1.101.3.4.2.1',  # sha256
+        '2.16.840.1.101.3.4.2.2',  # sha384
+        '2.16.840.1.101.3.4.2.3',  # sha512
     ])
 
     def _parameters_spec(self):
@@ -128,7 +134,7 @@ class DigestAlgorithmId(ObjectIdentifier):
     }
 
 
-class DigestAlgorithm(Sequence):
+class DigestAlgorithm(_ForceNullParameters, Sequence):
     _fields = [
         ('algorithm', DigestAlgorithmId),
         ('parameters', Any, {'optional': True}),
